@@ -1,121 +1,130 @@
-catmeth <- function(method, method.tau=NULL,
-                    sm="", k.all,
-                    hakn=FALSE, metaprop=FALSE,
-                    trimfill=FALSE,
-                    tau.common=FALSE,
-                    tau.preset=NULL,
-                    metabin=FALSE,
-                    metainc=FALSE,
-                    sparse=FALSE,
-                    incr=NULL,
-                    allincr=FALSE,
-                    addincr=FALSE,
-                    doublezeros = FALSE,
-                    MH.exact=FALSE,
-                    method.ci=NULL,
-                    metacont=FALSE,
-                    pooledvar=FALSE,
+catmeth <- function(method,
+                    method.tau = NULL,
+                    sm = "",
+                    k.all,
+                    hakn = FALSE,
+                    metaprop = FALSE,
+                    trimfill = FALSE,
+                    tau.common = FALSE,
+                    tau.preset = NULL,
+                    metabin = FALSE,
+                    metainc = FALSE,
+                    sparse = FALSE,
+                    incr = NULL,
+                    allincr = FALSE,
+                    addincr = FALSE,
+                    doublezeros  =  FALSE,
+                    MH.exact = FALSE,
+                    method.ci = NULL,
+                    metacont = FALSE,
+                    pooledvar = FALSE,
                     method.smd,
                     sd.glass,
-                    exact.smd=FALSE,
-                    model.glmm){
+                    exact.smd = FALSE,
+                    model.glmm,
+                    pscale = 1) {
   
   if (is.null(doublezeros)) doublezeros <- FALSE
   
-  if  (sm=="PFT")
+  if  (sm == "PFT")
     sm.details <- "\n- Freeman-Tukey double arcsine transformation"
-  else if (sm=="PAS")
+  else if (sm == "PAS")
     sm.details <- "\n- Arcsine transformation"
-  else if (sm=="PLN")
+  else if (sm == "PLN")
     sm.details <- "\n- Log transformation"
-  else if (sm=="PLOGIT")
+  else if (sm == "PLOGIT")
     sm.details <- "\n- Logit transformation"
-  else if (sm=="PRAW")
+  else if (sm == "PRAW")
     sm.details <- "\n- Untransformed proportions"
-  else if (sm=="ZCOR")
+  else if (sm == "ZCOR")
     sm.details <- "\n- Fisher's z transformation of correlations"
-  else if (sm=="COR")
+  else if (sm == "COR")
     sm.details <- "\n- Untransformed correlations"
   else
     sm.details <- ""
   ##
-  if (metaprop && !is.null(method.ci)){
-    if  (method.ci=="CP")
+  if (metaprop && !is.null(method.ci)) {
+    if  (method.ci == "CP")
       method.ci.details <- "\n- Clopper-Pearson confidence interval for individual studies"
-    else if (method.ci=="WS")
+    else if (method.ci == "WS")
       method.ci.details <- "\n- Wilson Score confidence interval for individual studies"
-    else if (method.ci=="WSCC")
+    else if (method.ci == "WSCC")
       method.ci.details <- "\n- Wilson Score confidence interval with continuity correction for individual studies"
-    else if (method.ci=="AC")
+    else if (method.ci == "AC")
       method.ci.details <- "\n- Agresti-Coull confidence interval for individual studies"
-    else if (method.ci=="SA")
+    else if (method.ci == "SA")
       method.ci.details <- "\n- Simple approximation confidence interval for individual studies"
-    else if (method.ci=="SACC")
+    else if (method.ci == "SACC")
       method.ci.details <- "\n- Simple approximation confidence interval with continuity correction for individual studies"
-    else if (method.ci=="NAsm")
+    else if (method.ci == "NAsm")
       method.ci.details <- "\n- Normal approximation confidence interval for individual studies"
     ##
-    sm.details <- paste(sm.details, method.ci.details, sep="")
+    sm.details <- paste(sm.details, method.ci.details, sep = "")
   }
   ##
-  if (metacont && sm=="SMD" && !is.null(method.smd)){
-    if  (method.smd=="Hedges")
+  if (metacont && sm == "SMD" && !is.null(method.smd)) {
+    if  (method.smd == "Hedges")
       if (exact.smd)
         method.details <- "\n- Hedges' g (bias corrected standardised mean difference; using exact formulae)"
       else
         method.details <- "\n- Hedges' g (bias corrected standardised mean difference)"
-    else if  (method.smd=="Cohen")
+    else if  (method.smd == "Cohen")
       if (exact.smd)
         method.details <- "\n- Cohen's d (standardised mean difference; using exact formulae)"
       else
         method.details <- "\n- Cohen's d (standardised mean difference)"
-    else if  (method.smd=="Glass"){
-      if (!is.null(sd.glass) && sd.glass=="control")
+    else if  (method.smd == "Glass") {
+      if (!is.null(sd.glass) && sd.glass == "control")
         method.details <- "\n- Glass' delta (standardised mean difference; based on control group)"
-      else if (!is.null(sd.glass) && sd.glass=="experimental")
+      else if (!is.null(sd.glass) && sd.glass == "experimental")
         method.details <- "\n- Glass' delta (standardised mean difference; based on experimental group)"
     }
     ##
-    sm.details <- paste(sm.details, method.details, sep="")
+    sm.details <- paste(sm.details, method.details, sep = "")
   }
   ##
-  if (metabin | metainc | metaprop){
-    if (!(sm=="ASD" | method=="Peto")){
-      if (addincr){
-        if (incr=="TACC")
+  if (metabin | metainc | metaprop) {
+    if (!(sm == "ASD" | method == "Peto")) {
+      if (addincr) {
+        if (incr == "TACC")
           sm.details <- paste(sm.details,
                               "\n- Treatment arm continuity correction in all studies",
-                              sep="")
-        else if (incr!=0)
+                              if (method == "GLMM") "\n  (only used to calculate individual study results)",
+                              sep = "")
+        else if (incr != 0)
           sm.details <- paste(sm.details,
                               "\n- Continuity correction of ", round(incr, 4),
-                              " in all studies", sep="")
-        else
-          sm.details <- ""
+                              " in all studies",
+                              if (method == "GLMM") "\n  (only used to calculate individual study results)",
+                              sep = "")
       }
-      else if (sparse){
-        if (allincr==FALSE)
-          if (incr=="TACC")
+      else if (sparse) {
+        if (allincr == FALSE) {
+          if (incr == "TACC")
             sm.details <- paste(sm.details,
                                 "\n- Treatment arm continuity correction in studies with zero cell frequencies",
-                                sep="")
-          else if (incr!=0)
+                                if (method == "GLMM") "\n  (only used to calculate individual study results)",
+                                sep = "")
+          else if (incr != 0)
             sm.details <- paste(sm.details,
                                 "\n- Continuity correction of ", round(incr, 4),
-                                " in studies with zero cell frequencies", sep="")
-          else
-            sm.details <- ""
-        else
-          if (incr=="TACC")
+                                " in studies with zero cell frequencies",
+                                if (method == "GLMM") "\n  (only used to calculate individual study results)",
+                                sep = "")
+        }
+        else {
+          if (incr == "TACC")
             sm.details <- paste(sm.details,
                                 "\n- Treatment arm continuity correction in all studies",
-                                sep="")
-          else if (incr!=0)
+                                if (method == "GLMM") "\n  (only used to calculate individual study results)",
+                               sep = "")
+          else if (incr != 0)
             sm.details <- paste(sm.details,
                                 "\n- Continuity correction of ", round(incr, 4),
-                                " in all studies", sep="")
-          else
-            sm.details <- ""
+                                " in all studies",
+                                if (method == "GLMM") "\n  (only used to calculate individual study results)",
+                                sep = "")
+        }
         ##
         if (doublezeros)
           sm.details <- paste(sm.details,
@@ -125,28 +134,35 @@ catmeth <- function(method, method.tau=NULL,
   }
   
   
+  if (pscale != 1)
+    sm.details <- paste(sm.details,
+                        "\n- Events per ",
+                        format(pscale, scientific = FALSE),
+                        " observations", sep = "")
+  
+  
   lab.method.details <- ""
   ##
   if (is.null(method.tau))
     lab.method.tau <- ""
   else {
-    if (!is.null(tau.preset)){
+    if (!is.null(tau.preset)) {
       tau2 <- tau.preset^2
       if (tau2 > 0 & tau2 < 0.0001)
         tau2 <- paste("tau^2", format.tau(tau2))
       else
         tau2 <- paste("tau^2 = ",
-                      ifelse(tau2==0,
+                      ifelse(tau2 == 0,
                              "0",
-                             format(round(tau2, 4), 4, nsmall=4, scientific=FALSE)),
-                      sep="")
+                             format(round(tau2, 4), 4, nsmall = 4, scientific = FALSE)),
+                      sep = "")
       ##
       lab.method.tau <- paste("\n- Preset between-study variance: ",
-                              tau2, sep="")
+                              tau2, sep = "")
       ##
       lab.method.details <- lab.method.tau
     }
-    else{
+    else {
       i.lab.method.tau <- charmatch(method.tau,
                                     c("DL", "PM", "REML", "ML", "HS", "SJ", "HE", "EB"),
                                     nomatch = NA)
@@ -161,14 +177,14 @@ catmeth <- function(method, method.tau=NULL,
                           "\n- Empirical Bayes estimator for tau^2")[i.lab.method.tau]
       ##
       if (tau.common)
-        lab.method.tau <- paste(lab.method.tau, " (assuming common tau^2 in subgroups)", sep="")
+        lab.method.tau <- paste(lab.method.tau, " (assuming common tau^2 in subgroups)", sep = "")
       ##
       if (hakn)
         lab.hakn <- "\n- Hartung-Knapp adjustment for random effects model"
       else
         lab.hakn <- ""
       ##      
-      lab.method.details <- paste(lab.method.tau, lab.hakn, sep="")
+      lab.method.details <- paste(lab.method.tau, lab.hakn, sep = "")
     }
   }
   ##
@@ -176,14 +192,14 @@ catmeth <- function(method, method.tau=NULL,
                      c("MH", "Peto", "Inverse", "Cochran", "GLMM"),
                      nomatch = NA)
   ##
-  if ((metabin|metainc) & imeth==1 & (sparse | addincr))
+  if ((metabin|metainc) & imeth == 1 & (sparse | addincr))
     if (MH.exact | metainc)
       lab.method.details <- paste(" (without continuity correction)",
-                                  lab.method.details, sep="")
+                                  lab.method.details, sep = "")
   ##
   if (metacont && !is.null(pooledvar) && pooledvar)
     lab.method.details <- paste(" (with pooled variance for individual studies)",
-                                lab.method.details, sep="")
+                                lab.method.details, sep = "")
   ##
   method <- c("\n- Mantel-Haenszel method",
               "\n- Peto method",
@@ -209,20 +225,20 @@ catmeth <- function(method, method.tau=NULL,
       method <- "\n- Random intercept logistic regression model"
   }
   ##
-  method <- paste(method, lab.method.details, sep="")
+  method <- paste(method, lab.method.details, sep = "")
   ##
-  if (k.all > 1){
-    cat(paste("\nDetails on meta-analytical method:", method, sep=""))
+  if (k.all > 1) {
+    cat(paste("\nDetails on meta-analytical method:", method, sep = ""))
     if (trimfill)
       cat("\n- Trim-and-fill method to adjust for funnel plot asymmetry")
   }
   else
-    cat(paste("\nDetails:", method, sep=""))
+    cat(paste("\nDetails:", method, sep = ""))
   ##
-  if (sm.details!="")
+  if (sm.details != "")
     cat(sm.details,
         "\n",
-        sep="")
+        sep = "")
   else
     cat("\n")
   
