@@ -1,31 +1,32 @@
 metacor <- function(cor, n, studlab,
                     ##
-                    data=NULL, subset=NULL,
+                    data = NULL, subset = NULL,
                     ##
-                    sm=.settings$smcor,
+                    sm = .settings$smcor,
                     ##
-                    level=.settings$level, level.comb=.settings$level.comb,
-                    comb.fixed=.settings$comb.fixed,
-                    comb.random=.settings$comb.random,
+                    level = .settings$level, level.comb = .settings$level.comb,
+                    comb.fixed = .settings$comb.fixed,
+                    comb.random = .settings$comb.random,
                     ##
-                    hakn=.settings$hakn,
-                    method.tau=.settings$method.tau,
-                    tau.preset=NULL, TE.tau=NULL,
-                    tau.common=.settings$tau.common,
+                    hakn = .settings$hakn,
+                    method.tau = .settings$method.tau,
+                    tau.preset = NULL, TE.tau = NULL,
+                    tau.common = .settings$tau.common,
                     ##
-                    prediction=.settings$prediction,
-                    level.predict=.settings$level.predict,
+                    prediction = .settings$prediction,
+                    level.predict = .settings$level.predict,
                     ##
-                    method.bias=.settings$method.bias,
+                    method.bias = .settings$method.bias,
                     ##
-                    backtransf=.settings$backtransf,
-                    title=.settings$title, complab=.settings$complab,
-                    outclab="",
+                    backtransf = .settings$backtransf,
+                    title = .settings$title, complab = .settings$complab,
+                    outclab = "",
                     ##
-                    byvar, bylab, print.byvar=.settings$print.byvar,
+                    byvar, bylab, print.byvar = .settings$print.byvar,
+                    byseparator = .settings$byseparator,
                     ##
-                    keepdata=.settings$keepdata
-                    ){
+                    keepdata = .settings$keepdata
+                    ) {
   
   
   ##
@@ -110,11 +111,11 @@ metacor <- function(cor, n, studlab,
   ##
   ## Additional checks
   ##
-  if (missing.byvar & tau.common){
+  if (missing.byvar & tau.common) {
     warning("Value for argument 'tau.common' set to FALSE as argument 'byvar' is missing.")
     tau.common <- FALSE
   }
-  if (!missing.byvar & !tau.common & !is.null(tau.preset)){
+  if (!missing.byvar & !tau.common & !is.null(tau.preset)) {
     warning("Argument 'tau.common' set to TRUE as argument tau.preset is not NULL.")
     tau.common <- TRUE
   }
@@ -130,7 +131,7 @@ metacor <- function(cor, n, studlab,
         (length(subset) > k.All))
       stop("Length of subset is larger than number of studies.")
   ##  
-  if (!missing.byvar){
+  if (!missing.byvar) {
     chkmiss(byvar)
     byvar.name <- byvarname(mf[[match("byvar", names(mf))]])
     bylab <- if (!missing(bylab) && !is.null(bylab)) bylab else byvar.name
@@ -143,9 +144,9 @@ metacor <- function(cor, n, studlab,
   ##     (if argument keepdata is TRUE)
   ##
   ##
-  if (keepdata){
+  if (keepdata) {
     if (nulldata)
-      data <- data.frame(.cor=cor)
+      data <- data.frame(.cor = cor)
     else
       data$.cor <- cor
     ##
@@ -155,10 +156,10 @@ metacor <- function(cor, n, studlab,
     if (!missing.byvar)
       data$.byvar <- byvar
     ##
-    if (!missing.subset){
+    if (!missing.subset) {
       if (length(subset) == dim(data)[1])
         data$.subset <- subset
-      else{
+      else {
         data$.subset <- FALSE
         data$.subset[subset] <- TRUE
       }
@@ -171,7 +172,7 @@ metacor <- function(cor, n, studlab,
   ## (6) Use subset for analysis
   ##
   ##
-  if (!missing.subset){
+  if (!missing.subset) {
     cor <- cor[subset]
     n   <- n[subset]
     studlab <- studlab[subset]
@@ -189,7 +190,7 @@ metacor <- function(cor, n, studlab,
   ##
   ## No meta-analysis for a single study
   ##
-  if (k.all == 1){
+  if (k.all == 1) {
     comb.fixed <- FALSE
     comb.random <- FALSE
     prediction <- FALSE
@@ -198,7 +199,7 @@ metacor <- function(cor, n, studlab,
   ## Check variable values
   ##
   chknumeric(cor, -1, 1)
-  chknumeric(n, 0, zero=TRUE)
+  chknumeric(n, 0, zero = TRUE)
   
   
   ##
@@ -206,13 +207,13 @@ metacor <- function(cor, n, studlab,
   ## (7) Calculate results for individual studies
   ##
   ##
-  if (sm=="ZCOR"){
-    TE   <- 0.5 * log((1 + cor)/(1 - cor))
-    seTE <- sqrt(1/(n - 3))
+  if (sm == "ZCOR") {
+    TE   <- 0.5 * log((1 + cor) / (1 - cor))
+    seTE <- sqrt(1 / (n - 3))
   }
-  if (sm=="COR"){
+  if (sm == "COR") {
     TE <- cor
-    seTE <- sqrt((1-cor^2)^2/(n-1))
+    seTE <- sqrt((1 - cor^2)^2 / (n - 1))
   }
   
   
@@ -223,30 +224,30 @@ metacor <- function(cor, n, studlab,
   ##
   m <- metagen(TE, seTE, studlab,
                ##
-               sm=sm,
-               level=level,
-               level.comb=level.comb,
-               comb.fixed=comb.fixed,
-               comb.random=comb.random,
+               sm = sm,
+               level = level,
+               level.comb = level.comb,
+               comb.fixed = comb.fixed,
+               comb.random = comb.random,
                ##
-               hakn=hakn,
-               method.tau=method.tau,
-               tau.preset=tau.preset,
-               TE.tau=TE.tau,
-               tau.common=FALSE,
+               hakn = hakn,
+               method.tau = method.tau,
+               tau.preset = tau.preset,
+               TE.tau = TE.tau,
+               tau.common = FALSE,
                ##
-               prediction=prediction,
-               level.predict=level.predict,
+               prediction = prediction,
+               level.predict = level.predict,
                ##
-               method.bias=method.bias,
+               method.bias = method.bias,
                ##
-               backtransf=backtransf,
-               title=title, complab=complab, outclab=outclab,
+               backtransf = backtransf,
+               title = title, complab = complab, outclab = outclab,
                ##
-               keepdata=FALSE,
-               warn=FALSE)
+               keepdata = FALSE,
+               warn = FALSE)
   ##
-  if (!missing.byvar & tau.common){
+  if (!missing.byvar & tau.common) {
     ## Estimate common tau-squared across subgroups
     hcc <- hetcalc(TE, seTE, method.tau,
                    TE.tau,
@@ -259,7 +260,7 @@ metacor <- function(cor, n, studlab,
   ## (9) Generate R object
   ##
   ##
-  res <- list(cor=cor, n=n)
+  res <- list(cor = cor, n = n)
   ##
   ## Add meta-analysis results
   ## (after removing unneeded list elements)
@@ -278,7 +279,7 @@ metacor <- function(cor, n, studlab,
   ##
   res$call <- match.call()
   ##
-  if (keepdata){
+  if (keepdata) {
     res$data <- data
     if (!missing.subset)
       res$subset <- subset
@@ -288,17 +289,18 @@ metacor <- function(cor, n, studlab,
     ##
   ## Add results from subgroup analysis
   ##
-  if (!missing.byvar){
+  if (!missing.byvar) {
     res$byvar <- byvar
     res$bylab <- bylab
     res$print.byvar <- print.byvar
+    res$byseparator <- byseparator
     res$tau.common <- tau.common
     ##
     if (!tau.common)
       res <- c(res, subgroup(res))
     else if (!is.null(tau.preset))
       res <- c(res, subgroup(res, tau.preset))
-    else{
+    else {
       res <- c(res, subgroup(res, hcc$tau))
       res$Q.w.random <- hcc$Q
       res$df.Q.w.random <- hcc$df.Q
@@ -309,6 +311,8 @@ metacor <- function(cor, n, studlab,
     res$event.w <- NULL
     res$n.e.w <- NULL
     res$n.c.w <- NULL
+    res$time.e.w <- NULL
+    res$time.c.w <- NULL
   }
   ##
   class(res) <- c(fun, "meta")
