@@ -1,72 +1,77 @@
-xlab <- function(sm, backtransf){
+xlab <- function(sm, backtransf, pscale = 1) {
 
   res <- NULL
   
-  if (sm=="SMD")
+  if (sm == "SMD")
     res <- "Standardised mean difference"
   ##
-  else if (sm=="WMD"|sm=="MD")
+  else if (sm == "WMD" | sm == "MD")
     res <- "Mean difference"
   ##
-  else if (sm=="COR")
+  else if (sm == "COR")
     res <- "Correlation"
   ##
-  else if (sm=="RD" )
+  else if (sm == "RD")
     res <- "Risk Difference"
   ##
-  else if (sm=="ASD" )
+  else if (sm == "ASD")
     res <- "Arcus Sinus Difference"
   ##
-  else if (sm=="IRD" )
+  else if (sm == "IRD")
     res <- "Incidence Rate Difference"
   ##
-  else if (backtransf){
-    if (sm=="OR" )
+  else if (backtransf) {
+    if (sm == "OR")
       res <- "Odds Ratio"
-    else if (sm=="RR" )
+    else if (sm == "RR")
       res <- "Risk Ratio"
     ##
-    else if (sm=="HR" )
+    else if (sm == "HR")
       res <- "Hazard Ratio"
     ##
-    else if (sm=="IRR" )
+    else if (sm == "IRR")
       res <- "Incidence Rate Ratio"
     ##
-    else if (sm=="ZCOR")
+    else if (sm == "ZCOR")
       res <- "Correlation"
     ##
     else if (sm %in% c("PFT", "PAS", "PLN", "PLOGIT", "PRAW"))
-      res <- ""
+      if (pscale == 1)
+        res <- ""
+      else
+        res <- paste("Events per",
+                     format(pscale, scientific = FALSE),
+                     "observations")
   }
-  else{
-    if (sm=="OR" )
+  else {
+    if (sm == "OR")
       res <- "Log Odds Ratio"
     ##
-    else if (sm=="RR" )
+    else if (sm == "RR")
       res <- "Log Risk Ratio"
     ##
-    else if (sm=="HR" )
+    else if (sm == "HR")
       res <- "Log Hazard Ratio"
     ##
-    else if (sm=="IRR" )
+    else if (sm == "IRR")
       res <- "Log Incidence Rate Ratio"
     ##
-    else if (sm=="ZCOR")
+    else if (sm == "ZCOR")
       res <- "Fisher's z transformed correlation"
     ##
-    else if (sm=="PFT")
+    else if (sm == "PFT")
       res <- "Freeman-Tukey Double Arcsine Transformed Proportion"
     ##
-    else if (sm=="PAS")
+    else if (sm == "PAS")
       res <- "Arcsine Transformed Proportion"
     ##
-    else if (sm=="PLN")
+    else if (sm == "PLN")
       res <- "Log Transformed Proportion"
     ##
-    else if (sm=="PLOGIT")
+    else if (sm == "PLOGIT")
       res <- "Logit Transformed Proportion"
     ##
-    else if (sm=="PRAW")
+    else if (sm == "PRAW")
       res <- "Untransformed Proportion"
   }
   
